<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Notifications</source>
        <translation>Uyarılar</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n saniye</numerusform><numerusform>%n saniye</numerusform></translation>
    </message>
    <message>
        <source>Number of quoted characters</source>
        <translation>Alıntı karakter sayısı</translation>
    </message>
    <message>
        <source>System notifications</source>
        <translation>Sistem uyarıları</translation>
    </message>
    <message>
        <source>Use custom expiration timeout</source>
        <translation>Özel son kullanım zaman aşımını kullan</translation>
    </message>
    <message>
        <source>Expiration timeout</source>
        <translation>Son kullanım zaman aşımı</translation>
    </message>
    <message>
        <source>Show message content</source>
        <translation>Mesaj içeriğini göster</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Hiçbir Zaman</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Ayarlar</translation>
    </message>
</context>
</TS>